@@ -23,12 +23,12 @@ import (
 	"github.com/blacktop/go-macho/types"
 	"github.com/blacktop/ipsw/internal/commands/dsc"
 	"github.com/blacktop/ipsw/internal/commands/extract"
-	kcmd "github.com/blacktop/ipsw/internal/commands/kernel"
 	"github.com/blacktop/ipsw/internal/demangle"
 	"github.com/blacktop/ipsw/internal/search"
 	"github.com/blacktop/ipsw/internal/swift"
 	"github.com/blacktop/ipsw/internal/syms/server"
 	"github.com/blacktop/ipsw/pkg/disass"
+	"github.com/blacktop/ipsw/pkg/signature"
 	"github.com/fatih/color"
 )
 
@@ -761,43 +761,7 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 		}
 	}
 
-	/* SYMBOLICATE FILESYSTEM MACHOS */
-
 	machoFuncMap := make(map[string][]types.Function)
-	if err := search.ForEachMachoInIPSW(ipswPath, i.Config.PemDB, func(path string, m *macho.File) error {
-		if total == 0 {
-			return ErrDone // break
-		}
-		for idx, img := range i.Payload.BinaryImages {
-			if m.UUID() != nil && strings.EqualFold(img.UUID, m.UUID().UUID.String()) {
-				i.Payload.BinaryImages[idx].Path = path
-				i.Payload.BinaryImages[idx].Name = path
-				// i.Payload.BinaryImages[idx].Name = filepath.Base(path)
-				i.Payload.BinaryImages[idx].Slide = i.Payload.BinaryImages[idx].Base - m.GetBaseAddress()
-				for _, fn := range m.GetFunctions() {
-					if syms, err := m.FindAddressSymbols(fn.StartAddr); err == nil {
-						for _, sym := range syms {
-							fn.Name = sym.Name
-						}
-						fn.StartAddr += i.Payload.BinaryImages[idx].Slide
-						fn.EndAddr += i.Payload.BinaryImages[idx].Slide
-						machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
-					} else {
-						fn.StartAddr += i.Payload.BinaryImages[idx].Slide
-						fn.EndAddr += i.Payload.BinaryImages[idx].Slide
-						fn.Name = fmt.Sprintf("func_%x", fn.StartAddr)
-						machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
-					}
-				}
-				total--
-			}
-		}
-		return nil
-	}); err != nil {
-		if !errors.Is(err, ErrDone) {
-			return fmt.Errorf("failed to symbolicate: %w", err)
-		}
-	}
 
 	/* SYMBOLICATE KERNELCACHE */
 	{
@@ -818,16 +782,16 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 			kextSyms := make(map[string]map[uint64]string)
 			if i.Config.SignaturesDir != "" {
 				// parse signatures
-				sigs, err := kcmd.ParseSignatures(i.Config.SignaturesDir)
+				sigs, err := signature.Parse(i.Config.SignaturesDir)
 				if err != nil {
 					return fmt.Errorf("failed to parse signatures: %v", err)
 				}
 				// symbolicate kernelcache
 				log.WithField("kernelcache", filepath.Base(k)).Info("Symbolicating...")
 				for _, sig := range sigs {
-					syms, err := kcmd.Symbolicate(k, sig, true)
+					syms, err := signature.Symbolicate(k, sig, true)
 					if err != nil {
-						if errors.Is(err, kcmd.ErrUnsupportedVersion) {
+						if errors.Is(err, signature.ErrUnsupportedVersion) {
 							continue
 						}
 						return fmt.Errorf("failed to symbolicate kernelcache: %v", err)
@@ -835,6 +799,7 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 					kextSyms[sig.Target] = make(map[uint64]string)
 					kextSyms[sig.Target] = syms
 				}
+				log.WithField("kernelcache", filepath.Base(k)).Warn("No signatures found for kernelcache")
 			}
 
 			kc, err := macho.Open(k)
@@ -889,6 +854,42 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 		}
 	}
 
+	/* SYMBOLICATE FILESYSTEM MACHOS */
+	if err := search.ForEachMachoInIPSW(ipswPath, i.Config.PemDB, func(path string, m *macho.File) error {
+		if total == 0 {
+			return ErrDone // break
+		}
+		for idx, img := range i.Payload.BinaryImages {
+			if m.UUID() != nil && strings.EqualFold(img.UUID, m.UUID().UUID.String()) {
+				i.Payload.BinaryImages[idx].Path = path
+				i.Payload.BinaryImages[idx].Name = path
+				// i.Payload.BinaryImages[idx].Name = filepath.Base(path)
+				i.Payload.BinaryImages[idx].Slide = i.Payload.BinaryImages[idx].Base - m.GetBaseAddress()
+				for _, fn := range m.GetFunctions() {
+					if syms, err := m.FindAddressSymbols(fn.StartAddr); err == nil {
+						for _, sym := range syms {
+							fn.Name = sym.Name
+						}
+						fn.StartAddr += i.Payload.BinaryImages[idx].Slide
+						fn.EndAddr += i.Payload.BinaryImages[idx].Slide
+						machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
+					} else {
+						fn.StartAddr += i.Payload.BinaryImages[idx].Slide
+						fn.EndAddr += i.Payload.BinaryImages[idx].Slide
+						fn.Name = fmt.Sprintf("func_%x", fn.StartAddr)
+						machoFuncMap[i.Payload.BinaryImages[idx].Name] = append(machoFuncMap[i.Payload.BinaryImages[idx].Name], fn)
+					}
+				}
+				total--
+			}
+		}
+		return nil
+	}); err != nil {
+		if !errors.Is(err, ErrDone) {
+			return fmt.Errorf("failed to symbolicate: %w", err)
+		}
+	}
+
 	// print any binary images that are missing names
 	// for idx, img := range i.Payload.BinaryImages {
 	// 	if len(img.Name) == 0 {
@@ -1000,7 +1001,8 @@ func (i *Ips) Symbolicate210(ipswPath string) (err error) {
 				}
 				if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "absolute" {
 					continue // skip absolute
-				} else if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "kernelcache" {
+				} else if i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "kernelcache" ||
+					i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName == "kernelcache (__TEXT_EXEC)" {
 					if funcs, ok := machoFuncMap[i.Payload.ProcessByPid[pid].ThreadByID[tid].KernelFrames[idx].ImageName]; ok {
 						found := false
 						for _, fn := range funcs {
